from typing import List, Optional
from pydantic_settings import BaseSettings
from pydantic import validator, EmailStr
import secrets


class Settings(BaseSettings):
    PROJECT_NAME: str = "HR Platform API"
    API_V1_STR: str = "/api/v1"
    
    # SECURITY
    SECRET_KEY: str = secrets.token_urlsafe(32)
    # 60 minutes * 24 hours * 8 days = 8 days
    ACCESS_TOKEN_EXPIRE_MINUTES: int = 60 * 24 * 8
    
    # CORS
    BACKEND_CORS_ORIGINS: List[str] = ["*"]

    # First superuser
    FIRST_SUPERUSER: EmailStr = "admin@example.com"
    FIRST_SUPERUSER_PASSWORD: str = "admin123"

    # SQLITE DB
    SQLALCHEMY_DATABASE_URI: Optional[str] = None

    @validator("SQLALCHEMY_DATABASE_URI", pre=True)
    def assemble_db_connection(cls, v: Optional[str], values: dict) -> str:
        if v:
            return v
        from pathlib import Path
        DB_DIR = Path("/app") / "storage" / "db"
        DB_DIR.mkdir(parents=True, exist_ok=True)
        return f"sqlite:///{DB_DIR}/db.sqlite"

    class Config:
        case_sensitive = True
        env_file = ".env"


settings = Settings()